<?php

function mh_edition_lite_customizer($wp_customize) {

	/***** Register Custom Controls *****/

    class MH_Edition_Lite_Customize_Upgrade_Control extends WP_Customize_Control {
        public function render_content() {  ?>
        	<p class="mh-upgrade-thumb">
        		<img src="<?php echo get_template_directory_uri(); ?>/images/mh_edition.png" />
        	</p>
        	<p class="mh-upgrade-title">
        		<span class="customize-control-title">
        			<?php _e('Need more features and options?', 'mh-edition-lite'); ?>
        		</span>
        	</p>
        	<p class="mh-upgrade-text">
        		<span class="textfield">
        			<?php _e('If you run an awesome website and need more advanced features, options and custom widgets, you can upgrade to the premium version of this theme which comes with great additional features and custom widgets to customize your website.', 'mh-edition-lite'); ?>
        		</span>
			</p>
			<p class="mh-upgrade-button">
				<a href="http://www.mhthemes.com/themes/mh/edition/" target="_blank" class="button button-secondary">
					<?php _e('Click here for premium features', 'mh-edition-lite'); ?>
				</a>
			</p><?php
        }
    }

	/***** Add Panels *****/

	$wp_customize->add_panel('mh_edition_lite_theme_options', array('title' => __('Theme Options', 'mh-edition-lite'), 'description' => '', 'capability' => 'edit_theme_options', 'theme_supports' => '', 'priority' => 1));

	/***** Add Sections *****/

	$wp_customize->add_section('mh_edition_lite_general', array('title' => __('General', 'mh-edition-lite'), 'priority' => 1, 'panel' => 'mh_edition_lite_theme_options'));
	$wp_customize->add_section('mh_edition_lite_layout', array('title' => __('Layout', 'mh-edition-lite'), 'priority' => 2, 'panel' => 'mh_edition_lite_theme_options'));
	$wp_customize->add_section('mh_edition_lite_upgrade', array('title' => __('Upgrade to Premium', 'mh-edition-lite'), 'priority' => 3, 'panel' => 'mh_edition_lite_theme_options'));

    /***** Add Settings *****/

    $wp_customize->add_setting('mh_edition_lite_options[excerpt_length]', array('default' => 25, 'type' => 'option', 'sanitize_callback' => 'mh_sanitize_integer'));
    $wp_customize->add_setting('mh_edition_lite_options[excerpt_more]', array('default' => __('Read More', 'mh-edition-lite'), 'type' => 'option', 'sanitize_callback' => 'mh_sanitize_text'));
    $wp_customize->add_setting('mh_edition_lite_options[sidebar]', array('default' => 'right', 'type' => 'option', 'sanitize_callback' => 'mh_sanitize_select'));
    $wp_customize->add_setting('mh_edition_lite_options[premium_version_upgrade]', array('default' => '', 'type' => 'option', 'sanitize_callback' => 'esc_attr'));
    $wp_customize->add_setting('mh_edition_lite_options[full_bg]', array('default' => '', 'type' => 'option', 'sanitize_callback' => 'mh_sanitize_checkbox'));

    /***** Add Controls *****/

    $wp_customize->add_control('excerpt_length', array('label' => esc_html__('Custom Excerpt Length in Words', 'mh-edition-lite'), 'section' => 'mh_edition_lite_general', 'settings' => 'mh_edition_lite_options[excerpt_length]', 'priority' => 1, 'type' => 'text'));
    $wp_customize->add_control('excerpt_more', array('label' => esc_html__('Custom Excerpt More-Text', 'mh-edition-lite'), 'section' => 'mh_edition_lite_general', 'settings' => 'mh_edition_lite_options[excerpt_more]', 'priority' => 2, 'type' => 'text'));
    $wp_customize->add_control('sidebar', array('label' => esc_html__('Sidebar Position', 'mh-edition-lite'), 'section' => 'mh_edition_lite_layout', 'settings' => 'mh_edition_lite_options[sidebar]', 'priority' => 2, 'type' => 'select', 'choices' => array('left' => __('Left', 'mh-edition-lite'), 'right' => __('Right', 'mh-edition-lite'))));
	$wp_customize->add_control(new MH_Edition_Lite_Customize_Upgrade_Control($wp_customize, 'premium_version_upgrade', array('section' => 'mh_edition_lite_upgrade', 'settings' => 'mh_edition_lite_options[premium_version_upgrade]', 'priority' => 1)));
	$wp_customize->add_control('full_bg', array('label' => esc_html__('Scale Background Image to Full Size', 'mh-edition-lite'), 'section' => 'background_image', 'settings' => 'mh_edition_lite_options[full_bg]', 'priority' => 99, 'type' => 'checkbox'));
}
add_action('customize_register', 'mh_edition_lite_customizer');

/***** Data Sanitization *****/

function mh_sanitize_text($input) {
    return wp_kses_post(force_balance_tags($input));
}
function mh_sanitize_integer($input) {
    return strip_tags(intval($input));
}
function mh_sanitize_checkbox($input) {
    if ($input == 1) {
        return 1;
    } else {
        return '';
    }
}
function mh_sanitize_select($input) {
    $valid = array(
        'left' => __('Left', 'mh-edition-lite'),
        'right' => __('Right', 'mh-edition-lite')
    );
    if (array_key_exists($input, $valid)) {
        return $input;
    } else {
        return '';
    }
}

/***** Return Theme Options / Set Default Options *****/

if (!function_exists('mh_edition_lite_theme_options')) {
	function mh_edition_lite_theme_options() {
		$theme_options = wp_parse_args(
			get_option('mh_edition_lite_options', array()),
			mh_edition_lite_default_options()
		);
		return $theme_options;
	}
}

if (!function_exists('mh_edition_lite_default_options')) {
	function mh_edition_lite_default_options() {
		$default_options = array(
			'excerpt_length' => 25,
			'excerpt_more' => __('Read More', 'mh-edition-lite'),
			'sidebar' => 'right',
			'full_bg' => ''
		);
		return $default_options;
	}
}

/***** Enqueue Customizer CSS *****/

function mh_edition_lite_customizer_css() {
	wp_enqueue_style('mh-customizer-css', get_template_directory_uri() . '/admin/customizer.css', array());
}
add_action('customize_controls_print_styles', 'mh_edition_lite_customizer_css');

?>